<html>
<head>
<title>Password Change</title>
</head>

<body>
<form method="POST" action="{% url baseacct-password-change %}">
{% csrf_token %}
{{ form }}
<input type="submit" value="Change Password">
</form>
</body>
</html>
